summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_html_live_status.py
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2015-11-25 14:37:26 +0100
committerHolger Levsen <holger@layer-acht.org>2015-11-25 14:37:26 +0100
commit0eea9c96aa8c1d0942bd15b41ced6b6c883adb3d (patch)
tree809952361cb8a42c6b9dbee143c021718d7106df /bin/reproducible_html_live_status.py
parent17f4dff7c2bca424a9f34066934792d0d7b2d298 (diff)
downloadjenkins.debian.net-0eea9c96aa8c1d0942bd15b41ced6b6c883adb3d.tar.xz
reproducible: add just one new armhf builder job for now (and also fixup 69f0038 the last bit)
Diffstat (limited to 'bin/reproducible_html_live_status.py')
-rwxr-xr-xbin/reproducible_html_live_status.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_html_live_status.py b/bin/reproducible_html_live_status.py
index a7c3fe29..86439549 100755
--- a/bin/reproducible_html_live_status.py
+++ b/bin/reproducible_html_live_status.py
@@ -66,8 +66,8 @@ def generate_live_status_table(arch):
counter = 0
for row in rows:
counter += 1
- # the numbers 33 and 14 should really be derived from /var/lib/jenkins/jobs/reproducible_builder_${arch}_* instead of being hard-coded here...
- if ( arch == 'amd64' and counter == 33 ) or ( arch == 'armhf' and counter == 14 ):
+ # FIXME: the numbers 32 and 14 should really be derived from /var/lib/jenkins/jobs/reproducible_builder_${arch}_* instead of being hard-coded here...
+ if ( arch == 'amd64' and counter > 32 ) or ( arch == 'armhf' and counter > 14 ):
html += '<tr><td colspan="10">There are more builds marked as currently building in the database than there are ' + arch + ' build jobs. This does not compute, please investigate and fix the cause.</td></tr>'
suite = row[1]
arch = row[2]